@@ -41,6 +41,15 @@
 #define FAUDIODEPRECATED(msg) __attribute__((deprecated(msg)))
 #endif
 
+/* -Wpedantic nameless union/struct silencing */
+#ifndef FAUDIONAMELESS
+#ifdef __GNUC__
+#define FAUDIONAMELESS __extension__
+#else
+#define FAUDIONAMELESS
+#endif /* __GNUC__ */
+#endif /* FAUDIONAMELESS */
+
 #include <stdint.h>
 #include <stddef.h>
 
@@ -457,8 +466,8 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 
 #define FAUDIO_ABI_VERSION	0
 #define FAUDIO_MAJOR_VERSION	19
-#define FAUDIO_MINOR_VERSION	06
-#define FAUDIO_PATCH_VERSION	07
+#define FAUDIO_MINOR_VERSION	07
+#define FAUDIO_PATCH_VERSION	00
 
 #define FAUDIO_COMPILED_VERSION ( \
 	(FAUDIO_ABI_VERSION * 100 * 100 * 100) + \
